"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("@code-engine/utils");
const clone_error_1 = require("./clone-error");
const clone_file_1 = require("./clone-file");
/**
 * Returns a cloneable copy of the given context object.
 * @internal
 */
function cloneContext(context) {
    // tslint:disable-next-line: no-object-literal-type-assertion
    let clone = { ...context, log: undefined };
    clone.changedFiles = context.changedFiles.map(clone_file_1.cloneChangedFile);
    return clone;
}
exports.cloneContext = cloneContext;
/**
 * Creates a `BuildContext` object from a `ContextClone`.
 * @internal
 */
function createContext(messenger, messageId, context) {
    return {
        ...context,
        changedFiles: context.changedFiles.map((file) => utils_1.createChangedFile(file)),
        log: createLogger(messenger, messageId, context),
    };
}
exports.createContext = createContext;
/**
 * Creates a `Logger` object from a `ContextClone`.
 */
function createLogger(messenger, messageId, context) {
    function log(message, data) {
        if (typeof message === "string") {
            log.info(message, data);
        }
        else {
            log.error(message, data);
        }
    }
    log.info = (message, data) => {
        messenger.postReply(createLogReply("info" /* Info */, messageId, message, data));
    };
    log.debug = (message, data) => {
        if (context.debug) {
            messenger.postReply(createLogReply("debug" /* Debug */, messageId, message, data));
        }
    };
    log.warn = (warning, data) => {
        messenger.postReply(createLogReply("warning" /* Warning */, messageId, warning, data));
    };
    log.error = (error, data) => {
        messenger.postReply(createLogReply("error" /* Error */, messageId, error, data));
    };
    return log;
}
function createLogReply(level, to, msg, data) {
    let message = clone_error_1.cloneError(msg);
    return { type: "log", to, level, message, data };
}
//# sourceMappingURL=clone-context.js.map